import { Meta, Canvas, Controls } from "@storybook/blocks";
import * as ComponentStories from "./event-calendar.stories";

<Meta of={ComponentStories} name="Docs" />

# Event Calendar

**The `<ux-iws-event-calendar>` replaces the patternlab calendar implementation.**

The component requires an according API `endpoint`.

## Integration

### Slots

-   **form**
    -   must be used to provide input elements with required request parameters
    -   can be used to provide content or form elements that should be displayed above the filter
-   **filter**
    -   can be used to provide content that should be displayed above the filter tags
-   **no-results**
    -   should be used to display content if no event matches the current filter settings

```html
<ux-iws-event-calendar
    endpoint="/api/common/events/1.0/showFilteredEvents/?ttContentUid=21404&keywords=2,10,11,74,75,76,297"
    locale="de"
    current-date="2024-03-14"
    region-label="Region"
    region-placeholder="Weltweit"
    hall-label="Halle"
    booth-label="Stand"
>
    <!-- input elements with required request parameters -->
    <div slot="form">
        <input type="hidden" name="ttContentUid" value="21404" />
        <input type="hidden" name="keywords" value="2,10,11,74,75,76,297" />
    </div>
    <!-- content that should be displayed above the filter tags -->
    <div slot="filter">
        <span class="ux-label">Sie interessieren sich für</span>
    </div>
    <!-- content that should be displayed if no event matches the current filter settings -->
    <div slot="no-results">
        <p class="ux-text">
            Es wurden keine passenden Veranstaltungen gefunden.
        </p>
    </div>
</ux-iws-event-calendar>
```

### Preview (Mock Data)

<Canvas of={ComponentStories.Default}></Canvas>

## Integration with Tabs

For each event type, a `<ux-tab>` with an `<ux-iws-event-calendar>` element is rendered with the `<ux-tab-container>`.

Set the `event-type` prop to only show specific events in the tab.

```html
<ux-tab-container>
    <ux-tab name="exhibition" tab-id="tab-exibition">
        <ux-iws-event-calendar
            endpoint="/api/common/events/1.0/showFilteredEvents/?ttContentUid=21404&keywords=2,10,11,74,75,76,297"
            event-type="exhibition"
            locale="de"
            region-label="Region"
            region-placeholder="Weltweit"
        >
            <!-- content that should be displayed above the filter tags -->
            <div slot="filter">
                <span class="ux-label">Sie interessieren sich für</span>
            </div>
            <!-- content that should be displayed if no event matches the current filter settings -->
            <div slot="no-results">
                <p class="ux-text">
                    Es wurden keine passenden Veranstaltungen gefunden.
                </p>
            </div>
        </ux-iws-event-calendar>
    </ux-tab>
</ux-tab-container>
```

### Preview with Tabs (Real Data)

The displayed events are limited to 5 in this example.

<Canvas of={ComponentStories.EventCalendarTabs}></Canvas>

## Static Rendering

The event list can be rendered statically by the backend (SEO).

Place a list `<ux-iws-event-calendar-item>` elements in the default slot of the `<ux-iws-event-calendar-item>`.

The initial events will be hidden as soon as the events have been requested from the api.

```html
<ux-iws-event-calendar
    endpoint="/api/common/events/1.0/showFilteredEvents/?ttContentUid=21404&keywords=2,10,11,74,75,76,297"
    locale="de"
    region-label="Region"
    region-placeholder="Weltweit"
>
    <!-- BEGIN static event item -->
    <ux-iws-event-calendar-item
        itemscope=""
        itemtype="https://schema.org/Event"
    >
        <div class="ux-iws-event-calendar-item__date-container">
            <time itemprop="startDate" datetime="2024-07-03">
                <div class="ux-iws-event-calendar-item__year">2024</div>
                <div class="ux-iws-event-calendar-item__month">Jul</div>
                <div class="ux-iws-event-calendar-item__date">03 – 05</div>
            </time>
        </div>
        <div class="ux-iws-event-calendar-item__content-container">
            <div class="ux-iws-event-calendar-item__booth">
                Halle A Stand 09
            </div>
            <div class="ux-iws-event-calendar-item__title" itemprop="name">
                DIC EXPO - DISPLAY INNOVATION CONVENTION 2024
            </div>
            <div class="ux-iws-event-calendar-item__tags">
                <ux-tag>Laser Technology</ux-tag>
            </div>
            <div
                class="ux-iws-event-calendar-item__location"
                itemprop="location"
                itemscope=""
                itemtype="https://schema.org/Place"
            >
                <div
                    itemprop="addressCountry"
                    itemscope=""
                    itemtype="https://schema.org/PostalAddress"
                >
                    China
                </div>
            </div>
            <div class="ux-iws-event-calendar-item__links">
                <a
                    class="ux-button"
                    href="http://www.dicexpo.com/"
                    target="_blank"
                >
                    Messe, Ausstellung
                </a>
            </div>
        </div>
    </ux-iws-event-calendar-item>
    <!-- END static event item -->
</ux-iws-event-calendar>
```

<Canvas of={ComponentStories.EventCalendarStatic}></Canvas>

### Hide future events

If the `hide-future-events` flag is set, only the events of the selected month are shown.

<Canvas of={ComponentStories.EventCalendarHideFutureEvents}></Canvas>

## Developer Documentation

<Controls />
